@@ -1,17 +1,16 @@
+# -*- coding: utf-8 -*-
+
 import numpy as np
 
-from npbrain.core import ode_generator
-from npbrain.core import sde_generator
+from npbrain.core import integrate
 from npbrain.core.neuron import *
-from npbrain.profile import get_dt
-from npbrain.utils import helper
 
 __all__ = [
     'LIF'
 ]
 
 
-def LIF(geometry, method='euler', **kwargs):
+def LIF(geometry, method=None, tau=10., Vr=0., Vth=10., noise=0., ref=0., name='LIF'):
     """Leaky integrate-and-fire neuron model.
 
     Parameters
@@ -22,46 +21,35 @@ def LIF(geometry, method='euler', **kwargs):
     method : str, callable, dict
         The numerical integration method. Either a string with the name of a
         registered method (e.g. "euler") or a function.
-    kwargs : dict
+    tau : float
         Neuron parameters.
+    Vr : float
+        The reset potential.
+    Vth : float
+        The spike threshold.
+    noise : float, callable
+        The noise item.
+    ref : float
+        The refractory period.
+    name : str
+        The name of the neuron group.
 
     Returns
     -------
     neurons : Neurons
         The created neuron group.
     """
-    # base
-    # ----
-    name = kwargs.pop('name', 'LIF')
+
     var2index = {'V': 0}
     num, geometry = format_geometry(geometry)
-    dt = kwargs.pop('dt', get_dt())
 
-    # parameters
-    # ------------------
-    tau = kwargs.pop('tau', 10.)
-    V_reset = kwargs.pop('V_reset', 0.)
-    Vth = kwargs.pop('Vth', 10.)
-    noise = kwargs.pop('noise', 0.)
-    ref = kwargs.pop('ref', 0.)
-    # check parameters
-    helper.check_params(kwargs)
-
-    # integration function
-    # --------------------
-    f = helper.autojit(lambda V, t, Isyn: (-V + V_reset + Isyn) / tau)
-    if noise == 0.:
-        int_f = ode_generator(f, dt)
-    else:
-        int_f = sde_generator(f, noise / tau, dt, method)
-
-    # init state
-    # -----------
     state = initial_neu_state(1, num)
-    state[0] = V_reset
+    state[0] = Vr
+
+    @integrate(method=method, noise=noise / tau)
+    def int_f(V, t, Isyn):
+        return (-V + Vr + Isyn) / tau
 
-    # update function
-    # -------------------
     if ref > 0.:
         def update_state(neu_state, t):
             not_ref = (t - neu_state[-2]) > ref
@@ -72,11 +60,11 @@ def LIF(geometry, method='euler', **kwargs):
             V = int_f(V, t, Isyn)
             neu_state[0][not_ref_idx] = V
             spike_idx = judge_spike(neu_state, Vth, t)
-            neu_state[0][spike_idx] = V_reset
+            neu_state[0][spike_idx] = Vr
     else:
         def update_state(neu_state, t):
             neu_state[0] = int_f(neu_state[0], t, neu_state[-1])
             spike_idx = judge_spike(neu_state, Vth, t)
-            neu_state[0][spike_idx] = V_reset
+            neu_state[0][spike_idx] = Vr
 
     return Neurons(**locals())
