@@ -1,12 +1,15 @@
+# -*- coding: utf-8 -*-
+
 import copy
 import functools
 import types
 
 import numba as nb
 import numpy as np
+from numba.core.dispatcher import Dispatcher
 
-from npbrain.profile import get_numba_profile
-from npbrain.profile import is_numba_bk
+from npbrain.utils.profile import get_numba_profile
+from npbrain.utils.profile import is_numba_bk
 
 
 __all__ = [
@@ -116,10 +119,11 @@ def autojit(func):
         function.
     """
     if is_numba_bk():
-        if is_lambda_function(func):
+        if is_lambda_function(func) and not isinstance(func, Dispatcher):
             func = jit_lambda(func)
         else:
-            func = jit_function(func)
+            if not isinstance(func, Dispatcher):
+                func = jit_function(func)
     return func
 
 
@@ -239,7 +243,7 @@ class Dict(dict):
                     (not isinstance(v, dict))):
                 self[k] = v
             else:
-                self[k].update(v)
+                self[k].integrate(v)
 
     def __getnewargs__(self):
         return tuple(self.items())
@@ -277,7 +281,8 @@ ddict = default_dict
 # other helpers
 ##############################
 
-@autojit
+
+@nb.jit(**get_numba_profile())
 def clip(a, a_min, a_max):
     """Reproduce the ``clip`` function in NumPy.
 
